@@ -31,7 +31,7 @@ def perform_restore(coordinator):
 
     set_future_shards(new_coordinator, coordinator)
 
-    statements_schema, statements_data = get_nodes_pg_restore_statements(coordinator)
+    statements_data = get_nodes_pg_restore_statements(coordinator)
 
     # Rename shards before restore
     dump_rename_node_shards_to_old_file(new_coordinator, configuration)
@@ -46,9 +46,6 @@ def perform_restore(coordinator):
         if configuration.restore_coordinator_data:
             statements_data.append(new_coordinator.pg_restore_statement)
 
-        # Restore schema in nodes
-        run_statements_in_parallel(configuration, statements_schema)
-
         # Now restore data
         run_statements_in_parallel(configuration, statements_data)
 
